parse_calendar_year_full_standard_range

Function parse_calendar_year_full_standard_range 

pub(crate) fn parse_calendar_year_full_standard_range(
    input: &[u8],
    modifiers: CalendarYearFullStandardRange,
) -> Option<ParsedItem<'_, i32>>
Available on crate feature parsing only.
Parse the full calendar-based year.

This only supports four digits in order to avoid parsing ambiguities, so it cannot utilize the full range of supported years when the large-dates feature flag is enabled.