parse_iso_year_century_extended_range

Function parse_iso_year_century_extended_range 

pub(crate) fn parse_iso_year_century_extended_range(
    input: &[u8],
    modifiers: IsoYearCenturyExtendedRange,
) -> Option<ParsedItem<'_, (i16, bool)>>
Available on crate feature parsing only.
Parse all digits of the ISO week-based year except the last two.

This permits utilizing the full range of supported years, though at the cost of introducing parsing ambiguities.