pub(crate) fn parse_iso_year_full_extended_range(
input: &[u8],
modifiers: IsoYearFullExtendedRange,
) -> Option<ParsedItem<'_, i32>>Available on crate feature
parsing only.Expand description
Parse the full ISO-week based year.
This permits utilizing the full range of supported years, though at the cost of introducing parsing ambiguities.