parse_weekday_monday

Function parse_weekday_monday 

pub(crate) fn parse_weekday_monday(
    input: &[u8],
    modifiers: WeekdayMonday,
) -> Option<ParsedItem<'_, Weekday>>
Available on crate feature parsing only.
Parse the weekday component of a Date in the numerical format, where Monday is the first day of the week.`