pub(crate) fn parse_weekday_sunday(
input: &[u8],
modifiers: WeekdaySunday,
) -> Option<ParsedItem<'_, Weekday>>Available on crate feature
parsing only.Expand description
Parse the weekday component of a Date in the numerical format, where Sunday is the first day
of the week.`